**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco_labour2.gms
Sequence         2 - The farm model
Type             LP
GAMS language    3-dimensional tables. Indexed equations
Description
"A given farm can grow three types of crop, wheat, maize and tomato,
and use two different crop practices, extensive and intensive.
The area to be cultivated and technology to be used must be determined, knowing that :
The objective of the farmer is to maximize his income.

Needs are as follows :
                 Water needs (thousands of m3/ha)
Technology      Extensive        Intensive
Wheat            0               2
Maize            4               6
Tomato           3               5

                    Labour needs (h/ha)
          Technology            Season
                        Winter       Summer
Wheat     extensive        10        5
          intensive        15        10
Maize     extensive        10        35
          intensive        10        40
Tomato    extensive        10        70
          intensive        10        90

Yields and costs are as follows :
                    Yield (ton/ha)                        Cost (/ha)
Technology       Extensive        Intensive      Extensive        Intensive
Wheat             4.5             5.0             250             300
Maize             8.0             10.0            400             500
Tomato           13.0            16.0            1200            1350

The selling price of wheat is 150/ton, that of maize is 150/ton, and that of tomato 185/ton.
The farm area is 50 ha, and the farmer can work 2000 hours a year and has 150 thousand m3 for irrigation. "
The farmer now has the possibility of hiring workers at 10 per hour.

$Offtext


*----------                          DECLARATION                       ----------*
sets
C crops       /wheat, maize, tomato/
T Technology  /ext, int/
s Season      /winter, summer/
;

*----------                          DATA                       ----------*
scalar
LAND_A    land availability in hectares                     /50/
WATER_A   water availability                               /150/
PSLF      hourly price of hired labour                      /10/
;

parameter
LABOUR_A (S)  labour availability in hours
/Summer     1000
 winter     1000/
;

table
LN(C,T,S) labour needs per crop and technology (hours)
             winter     Summer
 wheat.ext     10         5
 wheat.int     15        10
 maize.ext     10        35
 maize.int     10        40
 tomato.ext    10        70
 tomato.int    10        90
;

table WATERN(C,T) water needs per crop and technique (thousands of m3)
             ext   int
 wheat        0     2
 maize        4     6
 tomato       3     5
;

table
YLD (C, T) yield per crop in tonnes per hectare
          ext     int
wheat     4.5     5.0
maize     8.0    10.0
tomato   13.0    16.0
;

parameter
PC (C)  selling price per crop in euros
/ wheat    150
  maize    150
  tomato   185/
;

table
COST (C, T) cost per crop in euros per ha
          ext    int
wheat     250    300
maize     400    500
tomato   1200   1350
;
parameter
GM(C, T) gross margin per crop in euros    ;
GM(C, T) = YLD(C, T)*PC(C)-COST(C, T);

*----------                         MODEL                          ----------*
variables
Z     total farm income  (euros)
;

positive variables
X    area per crop (hectares)
SLF(S) number of hours of hired labour  (hours)
;

equations
OBJECTIVE       objective function
LAND            land equation
LABOUR          labour equation
WATER           irrigation equation
;
OBJECTIVE..   sum ((C,T), GM(C, T)* X(C, T)) - sum(S, SLF(S)*PSLF)  =E= Z ;

LAND..        sum((C,T), X(C, T)) =l= LAND_A  ;

LABOUR(S)..   sum((C,T), LN(C, T, S)*X(C, T)) =L= LABOUR_A(S) + SLF(S);

WATER..       sum((C,T), WATERN(C,T)*X(C,T)) =l= WATER_A;

model modelS2 first example /all/;

*----------                        SOLUTION                         ----------*
solve modelS2 using LP maximizing Z;

Parameter RESULT(*,*);
RESULT(c,t) = X.L(c,t);

RESULT('Land', 'Total') = LAND.L;
RESULT('Land', 'Marginal')=LAND.M;
RESULT('Labour_Winter', 'Total') = LABOUR.L('winter');
RESULT('Labour_Winter', 'Marginal')= LABOUR.M('winter');
RESULT('Labour_Summer', 'Total') = LABOUR.L('summer');
RESULT('Labour_Summer', 'Marginal')=  LABOUR.M('summer');
RESULT('SLF_winter', 'Total')= slf.L('winter');
RESULT('SLF_summer', 'Total')= slf.L('summer');
RESULT('Water','Total') = WATER.L;
RESULT('Water', 'Marginal')= WATER.M;
RESULT(c,'TOTAL') = sum(t, X.L(c,t));
RESULT('Labour_hired_winter','Total')=slf.L('winter');
RESULT('Labour_hired_summer','Total')=slf.L('summer');
Display RESULT ;






